.. Misaka documentation master file, created by
   sphinx-quickstart on Tue Jan 31 23:19:09 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Misaka
======

The Python binding for Sundown, a markdown parsing library.

Misaka is made with Cython_ and C and provides the same/similar functionality as
Redcarpet_, the Ruby binding for Sundown_. The parser and renderer are decoupled.
This means you can make your own renderers.

The documentation is also available on `Read the Docs`_.


.. _Cython: http://cython.org/
.. _Redcarpet: https://github.com/tanoku/redcarpet
.. _Sundown: https://github.com/tanoku/sundown
.. _Read the Docs: http://readthedocs.org/projects/misaka/


Contents:

.. toctree::
   :maxdepth: 1

   news
   installation
   examples
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

